@@ -1,4 +1,6 @@
 package POE::Component::SmokeBox;
+$POE::Component::SmokeBox::VERSION = '0.52';
+#ABSTRACT: POE enabled CPAN smoke testing with added value.
 
 use strict;
 use warnings;
@@ -6,9 +8,6 @@ use POE qw(Component::SmokeBox::Backend Component::SmokeBox::JobQueue);
 use POE::Component::SmokeBox::Smoker;
 use POE::Component::SmokeBox::Job;
 use POE::Component::SmokeBox::Result;
-use vars qw($VERSION);
-
-$VERSION = '0.50';
 
 sub spawn {
   my $package = shift;
@@ -203,10 +202,18 @@ sub _unreg_ui {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox - POE enabled CPAN smoke testing with added value.
 
+=head1 VERSION
+
+version 0.52
+
 =head1 SYNOPSIS
 
   # A simple smoker that takes modules to smoke from @ARGV
@@ -394,16 +401,6 @@ Each result is a hashref:
   'term_kill', only present if the job was killed due to a poco shutdown event;
   'cb_kill', only present if the job was killed due to the callback returning false;
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright (C) Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::SmokeBox::Smoker>
@@ -416,4 +413,15 @@ L<POE::Component::SmokeBox::Backend>
 
 L<POE::Component::SmokeBox::Result>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
