@@ -1,4 +1,6 @@
 package POE::Component::SmokeBox::Backend;
+$POE::Component::SmokeBox::Backend::VERSION = '0.52';
+#ABSTRACT: smoker backend to POE::Component::SmokeBox
 
 use strict;
 use warnings;
@@ -13,9 +15,6 @@ use POE qw[Wheel::Run Filter::Line];
 use Digest::SHA qw[sha256_hex];
 use Env::Sanctify;
 use Module::Pluggable search_path => 'POE::Component::SmokeBox::Backend', sub_name => 'backends', except => 'POE::Component::SmokeBox::Backend::Base';
-use vars qw($VERSION);
-
-$VERSION = '0.50';
 
 my $GOT_KILLFAM;
 my $GOT_PTY;
@@ -429,12 +428,21 @@ sub _wheel_kill {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Backend - smoker backend to POE::Component::SmokeBox
 
+=head1 VERSION
+
+version 0.52
+
 =head1 SYNOPSIS
 
   use strict;
@@ -568,20 +576,21 @@ Plus any of the parameters given to one of the constructors, including arbitary
 Setting the environment variable C<PERL5_SMOKEBOX_DEBUG> will cause the component to spew out lots of
 information on STDERR.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright (C) Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::SmokeBox>
 
 L<POE::Component::SmokeBox::Backend::Base>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
