@@ -1,10 +1,9 @@
 package POE::Component::SmokeBox::Backend::Base;
+$POE::Component::SmokeBox::Backend::Base::VERSION = '0.52';
+#ABSTRACT: Base class for Backend smokers.
 
 use strict;
 use warnings;
-use vars qw($VERSION);
-
-$VERSION = '0.50';
 
 sub new {
   my $package = shift;
@@ -42,12 +41,21 @@ sub smoke {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Backend::Base - Base class for Backend smokers.
 
+=head1 VERSION
+
+version 0.52
+
 =head1 SYNOPSIS
 
   package POE::Component::SmokeBox::Backend::Example;
@@ -114,16 +122,6 @@ set your data in sub-classes.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright C<(c)> Chris Williams.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::SmokeBox::Backend>
@@ -134,4 +132,15 @@ L<POE::Component::SmokeBox::Backend::CPAN::Reporter>
 
 L<POE::Component::SmokeBox::Backend::CPANPLUS::YACSmoke>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
