@@ -1,11 +1,10 @@
 package POE::Component::SmokeBox::Backend::SmokeInABox;
+$POE::Component::SmokeBox::Backend::SmokeInABox::VERSION = '0.52';
+#ABSTRACT: a backend for Smoke In A Box smokers.
 
 use strict;
 use warnings;
 use base qw(POE::Component::SmokeBox::Backend::Base);
-use vars qw($VERSION);
-
-$VERSION = '0.50';
 
 sub _data {
   my $self = shift;
@@ -19,12 +18,21 @@ sub _data {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Backend::SmokeInABox - a backend for Smoke In A Box smokers.
 
+=head1 VERSION
+
+version 0.52
+
 =head1 DESCRIPTION
 
 POE::Component::SmokeBox::Backend::SmokeInABox is a L<POE::Component::SmokeBox::Backend> plugin that defines the
@@ -50,19 +58,19 @@ Returns [ 'bin/yactest-boxed' ]
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::SmokeBox::Backend>
 
-=cut
+=head1 AUTHOR
 
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
