@@ -1,11 +1,10 @@
 package POE::Component::SmokeBox::Backend::Test::Stress;
+$POE::Component::SmokeBox::Backend::Test::Stress::VERSION = '0.52';
+#ABSTRACT: a backend to stress test.
 
 use strict;
 use warnings;
 use base qw(POE::Component::SmokeBox::Backend::Base);
-use vars qw($VERSION);
-
-$VERSION = '0.50';
 
 sub _data {
   my $self = shift;
@@ -19,12 +18,21 @@ sub _data {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Backend::Test::Stress - a backend to stress test.
 
+=head1 VERSION
+
+version 0.52
+
 =head1 DESCRIPTION
 
 POE::Component::SmokeBox::Backend::Test::Stress is a L<POE::Component::SmokeBox::Backend> plugin used during the
@@ -32,19 +40,19 @@ L<POE::Component::SmokeBox> tests.
 
 It contains no moving parts.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams
-
-=head1 LICENSE
-
-Copyright C<(c)> Chris Williams.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::SmokeBox::Backend>
 
-=cut
+=head1 AUTHOR
 
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
