@@ -1,10 +1,9 @@
 package POE::Component::SmokeBox::Result;
+$POE::Component::SmokeBox::Result::VERSION = '0.52';
+#ABSTRACT: object defining SmokeBox job results.
 
 use strict;
 use warnings;
-use vars qw($VERSION);
-
-$VERSION = '0.50';
 
 sub new {
   my $package = shift;
@@ -23,12 +22,21 @@ sub results {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Result - object defining SmokeBox job results.
 
+=head1 VERSION
+
+version 0.52
+
 =head1 DESCRIPTION
 
 POE::Component::SmokeBox::Result is a class encapsulating the job results that are returned by
@@ -58,16 +66,6 @@ Returns a list of hashrefs representing job results.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams
-
-=head1 LICENSE
-
-Copyright C<(C)> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::SmokeBox>
@@ -76,4 +74,15 @@ L<POE::Component::SmokeBox::Backend>
 
 L<POE::Component::SmokeBox::JobQueue>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
