@@ -1,12 +1,12 @@
 package POE::Component::SmokeBox::Smoker;
+$POE::Component::SmokeBox::Smoker::VERSION = '0.52';
+#ABSTRACT: encapsulates a smoker object.
 
 use strict;
 use warnings;
 use Params::Check qw(check);
 use base qw(Object::Accessor);
-use vars qw($VERSION $VERBOSE);
-
-$VERSION = '0.50';
+use vars qw($VERBOSE);
 
 sub new {
   my $package = shift;
@@ -41,12 +41,21 @@ sub dump_data {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Smoker - encapsulates a smoker object.
 
+=head1 VERSION
+
+version 0.52
+
 =head1 SYNOPSIS
 
   use POE::Component::SmokeBox::Smoker;
@@ -150,16 +159,6 @@ Returns all the data contained in the object as a list.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams
-
-=head1 LICENSE
-
-Copyright C<(C)> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE::Component::SmokeBox>
@@ -168,4 +167,15 @@ L<POE::Component::SmokeBox::JobQueue>
 
 L<POE::Component::SmokeBox::Backend>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
